@@ -24,12 +24,11 @@
 #include <string.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <dbus/dbus-glib.h>
+#include <gio/gio.h>
 #include <gconf/gconf-client.h>
 
 #include "gpm-screensaver.h"
 #include "gpm-common.h"
-#include "egg-debug.h"
 
 static void     gpm_screensaver_finalize   (GObject		*object);
 
@@ -41,7 +40,7 @@ static void     gpm_screensaver_finalize   (GObject		*object);
 
 struct GpmScreensaverPrivate
 {
-	DBusGProxy		*proxy;
+	GDBusProxy		*proxy;
 	GConfClient		*conf;
 };
 
@@ -50,83 +49,10 @@ enum {
 	LAST_SIGNAL
 };
 
-#if 0
-static guint signals [LAST_SIGNAL] = { 0 };
-#endif
 static gpointer gpm_screensaver_object = NULL;
 
 G_DEFINE_TYPE (GpmScreensaver, gpm_screensaver, G_TYPE_OBJECT)
 
-#if 0
-
-/** Invoked when we get the AuthenticationRequestBegin from g-s when the user
- *  has moved their mouse and we are showing the authentication box.
- */
-static void
-gpm_screensaver_auth_begin (DBusGProxy     *proxy,
-			    GpmScreensaver *screensaver)
-{
-	egg_debug ("emitting auth-request : (%i)", TRUE);
-	g_signal_emit (screensaver, signals [AUTH_REQUEST], 0, TRUE);
-}
-
-/** Invoked when we get the AuthenticationRequestEnd from g-s when the user
- *  has entered a valid password or re-authenticated.
- */
-static void
-gpm_screensaver_auth_end (DBusGProxy     *proxy,
-			  GpmScreensaver *screensaver)
-{
-	egg_debug ("emitting auth-request : (%i)", FALSE);
-	g_signal_emit (screensaver, signals [AUTH_REQUEST], 0, FALSE);
-}
-
-/**
- * gpm_screensaver_proxy_connect_more:
- * @screensaver: This class instance
- **/
-static gboolean
-gpm_screensaver_proxy_connect_more (GpmScreensaver *screensaver)
-{
-	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
-
-	if (screensaver->priv->proxy == NULL) {
-		egg_warning ("not connected");
-		return FALSE;
-	}
-
-	/* get AuthenticationRequestBegin */
-	dbus_g_proxy_add_signal (screensaver->priv->proxy,
-				 "AuthenticationRequestBegin", G_TYPE_INVALID);
-	dbus_g_proxy_connect_signal (screensaver->priv->proxy,
-				     "AuthenticationRequestBegin",
-				     G_CALLBACK (gpm_screensaver_auth_begin),
-				     screensaver, NULL);
-
-	/* get AuthenticationRequestEnd */
-	dbus_g_proxy_add_signal (screensaver->priv->proxy,
-				 "AuthenticationRequestEnd", G_TYPE_INVALID);
-	dbus_g_proxy_connect_signal (screensaver->priv->proxy,
-				     "AuthenticationRequestEnd",
-				     G_CALLBACK (gpm_screensaver_auth_end),
-				     screensaver, NULL);
-
-	return TRUE;
-}
-
-/**
- * gpm_screensaver_proxy_disconnect_more:
- * @screensaver: This class instance
- **/
-static gboolean
-gpm_screensaver_proxy_disconnect_more (GpmScreensaver *screensaver)
-{
-	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
-	egg_debug ("gnome-screensaver disconnected from the session DBUS");
-	return TRUE;
-}
-#endif
-
 /**
  * gpm_screensaver_lock_enabled:
  * @screensaver: This class instance
@@ -154,13 +80,14 @@ gpm_screensaver_lock (GpmScreensaver *screensaver)
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
 	if (screensaver->priv->proxy == NULL) {
-		egg_warning ("not connected");
+		g_warning ("not connected");
 		return FALSE;
 	}
 
-	egg_debug ("doing gnome-screensaver lock");
-	dbus_g_proxy_call_no_reply (screensaver->priv->proxy,
-				    "Lock", G_TYPE_INVALID);
+	g_debug ("doing gnome-screensaver lock");
+	g_dbus_proxy_call (screensaver->priv->proxy,
+			   "Lock",
+			   NULL, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL, NULL);
 
 	/* When we send the Lock signal to g-ss it takes maybe a second
 	   or so to fade the screen and lock. If we suspend mid fade then on
@@ -174,7 +101,7 @@ gpm_screensaver_lock (GpmScreensaver *screensaver)
 		/* Sleep for 1/10s */
 		g_usleep (1000 * 100);
 		if (sleepcount++ > 50) {
-			egg_debug ("timeout waiting for gnome-screensaver");
+			g_debug ("timeout waiting for gnome-screensaver");
 			break;
 		}
 	}
@@ -185,43 +112,45 @@ gpm_screensaver_lock (GpmScreensaver *screensaver)
 /**
  * gpm_screensaver_add_throttle:
  * @screensaver: This class instance
- * @reason:      The reason for throttling
+ * @reason: The reason for throttling
  * Return value: Success value, or zero for failure
  **/
 guint
-gpm_screensaver_add_throttle (GpmScreensaver *screensaver,
-			      const char     *reason)
+gpm_screensaver_add_throttle (GpmScreensaver *screensaver, const char *reason)
 {
-	GError  *error = NULL;
-	gboolean ret;
-	guint32  cookie;
+	GError *error = NULL;
+	GVariant *retval = NULL;
+	guint32 cookie = 0;
 
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), 0);
 	g_return_val_if_fail (reason != NULL, 0);
 
 	if (screensaver->priv->proxy == NULL) {
-		egg_warning ("not connected");
-		return 0;
+		g_warning ("not connected to the screensaver");
+		goto out;
 	}
 
-	ret = dbus_g_proxy_call (screensaver->priv->proxy,
-				 "Throttle", &error,
-				 G_TYPE_STRING, "Power screensaver",
-				 G_TYPE_STRING, reason,
-				 G_TYPE_INVALID,
-				 G_TYPE_UINT, &cookie,
-				 G_TYPE_INVALID);
-	if (error) {
-		egg_debug ("ERROR: %s", error->message);
-		g_error_free (error);
-	}
-	if (!ret) {
+	retval = g_dbus_proxy_call_sync (screensaver->priv->proxy,
+					 "Throttle",
+					 g_variant_new ("(ss)",
+							"Power screensaver",
+							reason),
+					 G_DBUS_CALL_FLAGS_NONE,
+					 -1, NULL,
+					 &error);
+	if (retval == NULL) {
 		/* abort as the DBUS method failed */
-		egg_warning ("Throttle failed!");
-		return 0;
+		g_warning ("Throttle failed: %s", error->message);
+		g_error_free (error);
+		goto out;
 	}
 
-	egg_debug ("adding throttle reason: '%s': id %u", reason, cookie);
+	/* success */
+	g_variant_get (retval, "(u)", &cookie);
+	g_debug ("adding throttle reason: '%s': id %u", reason, cookie);
+out:
+	if (retval != NULL)
+		g_variant_unref (retval);
 	return cookie;
 }
 
@@ -231,33 +160,37 @@ gpm_screensaver_add_throttle (GpmScreensaver *screensaver,
 gboolean
 gpm_screensaver_remove_throttle (GpmScreensaver *screensaver, guint cookie)
 {
-	gboolean ret;
+	gboolean ret = FALSE;
+	GVariant *retval = NULL;
 	GError *error = NULL;
 
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
 	if (screensaver->priv->proxy == NULL) {
-		egg_warning ("not connected");
-		return FALSE;
+		g_warning ("not connected to the screensaver");
+		goto out;
 	}
 
-	egg_debug ("removing throttle: id %u", cookie);
-	ret = dbus_g_proxy_call (screensaver->priv->proxy,
-				 "UnThrottle", &error,
-				 G_TYPE_UINT, cookie,
-				 G_TYPE_INVALID,
-				 G_TYPE_INVALID);
-	if (error) {
-		egg_debug ("ERROR: %s", error->message);
-		g_error_free (error);
-	}
-	if (!ret) {
+	g_debug ("removing throttle: id %u", cookie);
+	retval = g_dbus_proxy_call_sync (screensaver->priv->proxy,
+					 "UnThrottle",
+					 g_variant_new ("(u)", cookie),
+					 G_DBUS_CALL_FLAGS_NONE,
+					 -1, NULL,
+					 &error);
+	if (retval == NULL) {
 		/* abort as the DBUS method failed */
-		egg_warning ("UnThrottle failed!");
+		g_warning ("UnThrottle failed!: %s", error->message);
+		g_error_free (error);
 		return FALSE;
 	}
 
-	return TRUE;
+	/* success */
+	ret = TRUE; 
+out:
+	if (retval != NULL)
+		g_variant_unref (retval);
+	return ret;
 }
 
 /**
@@ -268,28 +201,34 @@ gpm_screensaver_remove_throttle (GpmScreensaver *screensaver, guint cookie)
 gboolean
 gpm_screensaver_check_running (GpmScreensaver *screensaver)
 {
-	gboolean ret;
-	gboolean temp = TRUE;
+	GVariant *retval = NULL;
+	gboolean active = FALSE;
 	GError *error = NULL;
 
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
 	if (screensaver->priv->proxy == NULL) {
-		egg_warning ("not connected");
-		return FALSE;
+		g_warning ("not connected to screensaver");
+		goto out;
 	}
 
-	ret = dbus_g_proxy_call (screensaver->priv->proxy,
-				 "GetActive", &error,
-				 G_TYPE_INVALID,
-				 G_TYPE_BOOLEAN, &temp,
-				 G_TYPE_INVALID);
-	if (error) {
-		egg_debug ("ERROR: %s", error->message);
+	retval = g_dbus_proxy_call_sync (screensaver->priv->proxy,
+					 "GetActive",
+					 NULL, G_DBUS_CALL_FLAGS_NONE,
+					 -1, NULL, &error);
+
+	if (retval == NULL) {
+		g_debug ("ERROR: %s", error->message);
 		g_error_free (error);
+		goto out;
 	}
 
-	return ret;
+	/* success */
+	g_variant_get (retval, "(b)", &active);
+out:
+	if (retval != NULL)
+		g_variant_unref (retval);
+	return active;
 }
 
 /**
@@ -306,14 +245,16 @@ gpm_screensaver_poke (GpmScreensaver *screensaver)
 	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
 
 	if (screensaver->priv->proxy == NULL) {
-		egg_warning ("not connected");
+		g_warning ("not connected");
 		return FALSE;
 	}
 
-	egg_debug ("poke");
-	dbus_g_proxy_call_no_reply (screensaver->priv->proxy,
-				    "SimulateUserActivity",
-				    G_TYPE_INVALID);
+	g_debug ("poke");
+	g_dbus_proxy_call (screensaver->priv->proxy,
+			   "SimulateUserActivity",
+			   NULL, G_DBUS_CALL_FLAGS_NONE,
+			   -1, NULL, NULL, NULL);
+
 	return TRUE;
 }
 
@@ -327,38 +268,6 @@ gpm_screensaver_class_init (GpmScreensaverClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize = gpm_screensaver_finalize;
 	g_type_class_add_private (klass, sizeof (GpmScreensaverPrivate));
-
-#if 0
-	signals [AUTH_REQUEST] =
-		g_signal_new ("auth-request",
-			      G_TYPE_FROM_CLASS (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GpmScreensaverClass, auth_request),
-			      NULL,
-			      NULL,
-			      g_cclosure_marshal_VOID__BOOLEAN,
-			      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
-#endif
-}
-
-/**
- * gpm_screensaver_proxy_status_cb:
- * @proxy: The dbus raw proxy
- * @status: The status of the service, where TRUE is connected
- * @screensaver: This class instance
- **/
-static void
-gpm_screensaver_proxy_status_cb (DBusGProxy *proxy, gboolean status, GpmScreensaver *screensaver)
-{
-	g_return_if_fail (GPM_IS_SCREENSAVER (screensaver));
-
-#if 0
-	if (status) {
-		gpm_screensaver_proxy_connect_more (screensaver);
-	} else {
-		gpm_screensaver_proxy_disconnect_more (screensaver);
-	}
-#endif
 }
 
 /**
@@ -368,21 +277,25 @@ gpm_screensaver_proxy_status_cb (DBusGProxy *proxy, gboolean status, GpmScreensa
 static void
 gpm_screensaver_init (GpmScreensaver *screensaver)
 {
-	DBusGConnection *connection;
+	GDBusConnection *connection;
+	GError *error = NULL;
 
 	screensaver->priv = GPM_SCREENSAVER_GET_PRIVATE (screensaver);
 
-	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
-
-	screensaver->priv->proxy = dbus_g_proxy_new_for_name (connection,
-							      GS_LISTENER_SERVICE,
-							      GS_LISTENER_PATH,
-							      GS_LISTENER_INTERFACE);
-
-	g_signal_connect (screensaver->priv->proxy, "proxy-status",
-			  G_CALLBACK (gpm_screensaver_proxy_status_cb),
-			  screensaver);
-
+	connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL);
+	screensaver->priv->proxy =
+		g_dbus_proxy_new_sync (connection,
+			G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES |
+			G_DBUS_PROXY_FLAGS_DO_NOT_CONNECT_SIGNALS,
+			NULL,
+			GS_LISTENER_SERVICE,
+			GS_LISTENER_PATH,
+			GS_LISTENER_INTERFACE,
+			NULL, &error);
+	if (screensaver->priv->proxy == NULL) {
+		g_warning ("failed to setup screensaver proxy: %s", error->message);
+		g_error_free (error);
+	}
 	screensaver->priv->conf = gconf_client_get_default ();
 }
 
@@ -400,9 +313,6 @@ gpm_screensaver_finalize (GObject *object)
 	screensaver = GPM_SCREENSAVER (object);
 	screensaver->priv = GPM_SCREENSAVER_GET_PRIVATE (screensaver);
 
-#if 0
-	gpm_screensaver_proxy_disconnect_more (screensaver);
-#endif
 	g_object_unref (screensaver->priv->conf);
 	g_object_unref (screensaver->priv->proxy);
 
