@@ -26,8 +26,6 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
-#include "egg-debug.h"
-
 #include "gpm-screensaver.h"
 #include "gpm-dpms.h"
 #include "gpm-phone.h"
@@ -36,7 +34,6 @@
 #include "gpm-idletime.h"
 #include "gpm-array-float.h"
 
-
 /** ver:1.0 ***********************************************************/
 static GMainLoop *_test_loop = NULL;
 static guint _test_loop_timeout_id = 0;
@@ -158,7 +155,7 @@ static void
 gpm_test_idle_func_idle_changed_cb (GpmIdle *idle, GpmIdleMode mode, gpointer user_data)
 {
 	_mode = mode;
-	egg_debug ("idle-changed %s", gpm_idle_mode_to_string (mode));
+	g_debug ("idle-changed %s", gpm_idle_mode_to_string (mode));
 	_g_test_loop_quit ();
 }
 
@@ -173,7 +170,6 @@ gpm_test_idle_func (void)
 	g_assert (idle != NULL);
 
 	/* set up defaults */
-	gpm_idle_set_check_cpu (idle, FALSE);
 	gpm_idle_set_timeout_dim (idle, 4);
 	gpm_idle_set_timeout_blank (idle, 5);
 	gpm_idle_set_timeout_sleep (idle, 15);
@@ -301,7 +297,7 @@ gpm_test_phone_func (void)
 static void
 gpm_test_screensaver_func_auth_request_cb (GpmScreensaver *screensaver, gboolean auth, gpointer user_data)
 {
-	egg_debug ("auth request = %i", auth);
+	g_debug ("auth request = %i", auth);
 	test_got_request = auth;
 
 	_g_test_loop_quit ();
@@ -425,7 +421,6 @@ gpm_test_color_func (void)
 	g_assert_cmpint (color, ==, 0xffffff);
 }
 
-
 static void
 gpm_test_array_float_func (void)
 {
@@ -697,7 +692,6 @@ gpm_test_array_float_func (void)
 	gpm_array_float_free (kernel);
 }
 
-
 static void
 gpm_test_idletime_wait (guint time_ms)
 {
