@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef __GPM_TRAY_ICON_H
@@ -55,7 +55,7 @@ GpmTrayIcon	*gpm_tray_icon_new			(void);
 gboolean	 gpm_tray_icon_set_tooltip		(GpmTrayIcon	*icon,
 							 const gchar	*tooltip);
 gboolean	 gpm_tray_icon_set_icon			(GpmTrayIcon	*icon,
-							 const gchar	*filename);
+							 GIcon		*gicon);
 GtkStatusIcon	*gpm_tray_icon_get_status_icon		(GpmTrayIcon	*icon);
 
 G_END_DECLS
